@@ -132,7 +132,7 @@ Java_qdbm_Depot_dpput(JNIEnv *env, jclass myclass, jint index, jbyteArray key, j
   int rv;
   kbuf = (*env)->GetByteArrayElements(env, key, &ick);
   vbuf = (*env)->GetByteArrayElements(env, val, &icv);
-  rv = dpput(dptable[index], kbuf, ksiz, vbuf, vsiz, getdpdmode(dmode));
+  rv = dpput(dptable[index], (char *)kbuf, ksiz, (char *)vbuf, vsiz, getdpdmode(dmode));
   if(ick == JNI_TRUE) (*env)->ReleaseByteArrayElements(env, key, kbuf, JNI_ABORT);
   if(icv == JNI_TRUE) (*env)->ReleaseByteArrayElements(env, val, vbuf, JNI_ABORT);
   return rv;
@@ -146,7 +146,7 @@ Java_qdbm_Depot_dpout(JNIEnv *env, jclass myclass, jint index, jbyteArray key, j
   jboolean ick;
   int rv;
   kbuf = (*env)->GetByteArrayElements(env, key, &ick);
-  rv = dpout(dptable[index], kbuf, ksiz);
+  rv = dpout(dptable[index], (char *)kbuf, ksiz);
   if(ick == JNI_TRUE) (*env)->ReleaseByteArrayElements(env, key, kbuf, JNI_ABORT);
   return rv;
 }
@@ -162,11 +162,11 @@ Java_qdbm_Depot_dpget(JNIEnv *env, jclass myclass, jint index, jbyteArray key, j
   int vsiz;
   jbyteArray vbuf;
   kbuf = (*env)->GetByteArrayElements(env, key, &ick);
-  val = dpget(dptable[index], kbuf, ksiz, start, max, &vsiz);
+  val = dpget(dptable[index], (char *)kbuf, ksiz, start, max, &vsiz);
   if(ick == JNI_TRUE) (*env)->ReleaseByteArrayElements(env, key, kbuf, JNI_ABORT);
   if(val){
     vbuf = (*env)->NewByteArray(env, vsiz);
-    (*env)->SetByteArrayRegion(env, vbuf, 0, vsiz, val);
+    (*env)->SetByteArrayRegion(env, vbuf, 0, vsiz, (jbyte *)val);
     free(val);
   } else {
     vbuf = NULL;
@@ -182,7 +182,7 @@ Java_qdbm_Depot_dpvsiz(JNIEnv *env, jclass myclass, jint index, jbyteArray key,
   jboolean ick;
   int rv;
   kbuf = (*env)->GetByteArrayElements(env, key, &ick);
-  rv = dpvsiz(dptable[index], kbuf, ksiz);
+  rv = dpvsiz(dptable[index], (char *)kbuf, ksiz);
   if(ick == JNI_TRUE) (*env)->ReleaseByteArrayElements(env, key, kbuf, JNI_ABORT);
   return rv;
 }
@@ -204,7 +204,7 @@ Java_qdbm_Depot_dpiternext(JNIEnv *env, jclass myclass, jint index)
   val = dpiternext(dptable[index], &vsiz);
   if(val){
     vbuf = (*env)->NewByteArray(env, vsiz);
-    (*env)->SetByteArrayRegion(env, vbuf, 0, vsiz, val);
+    (*env)->SetByteArrayRegion(env, vbuf, 0, vsiz, (jbyte *)val);
     free(val);
   } else {
     vbuf = NULL;
@@ -320,7 +320,32 @@ Java_qdbm_Depot_dpremove(JNIEnv *env, jclass myclass, jstring name)
   tname = (*env)->GetStringUTFChars(env, name, &ic);
   rv = dpremove(tname);
   if(ic == JNI_TRUE) (*env)->ReleaseStringUTFChars(env, name, tname);
-  return rv ? 1 : 0;
+  return rv;
+}
+
+
+JNIEXPORT jbyteArray JNICALL
+Java_qdbm_Depot_dpsnaffle(JNIEnv *env, jclass myclass, jstring name, jbyteArray key, jint ksiz)
+{
+  jbyte *kbuf;
+  jboolean icn, ick;
+  const char *tname;
+  char *val;
+  int vsiz;
+  jbyteArray vbuf;
+  tname = (*env)->GetStringUTFChars(env, name, &icn);
+  kbuf = (*env)->GetByteArrayElements(env, key, &ick);
+  val = dpsnaffle(tname, (char *)kbuf, ksiz, &vsiz);
+  if(ick == JNI_TRUE) (*env)->ReleaseByteArrayElements(env, key, kbuf, JNI_ABORT);
+  if(icn == JNI_TRUE) (*env)->ReleaseStringUTFChars(env, name, tname);
+  if(val){
+    vbuf = (*env)->NewByteArray(env, vsiz);
+    (*env)->SetByteArrayRegion(env, vbuf, 0, vsiz, (jbyte *)val);
+    free(val);
+  } else {
+    vbuf = NULL;
+  }
+  return vbuf;
 }
 
 
